CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
30 lines
1.1 KiB
Plaintext
30 lines
1.1 KiB
Plaintext
// Copyright (c) 2026 Advanced Micro Devices, Inc.
|
|
// All rights reserved.
|
|
|
|
#include <hip/hip_runtime.h>
|
|
|
|
/// Element-wise vector addition kernel for multi-workgroup stress testing.
|
|
///
|
|
/// Each workgroup computes 64 contiguous elements of C = A + B.
|
|
/// The global thread ID determines which element each lane computes:
|
|
/// global_id = workgroup_id * 64 + thread_id
|
|
///
|
|
/// With 256 workgroups of 64 threads each, all 16384 elements are covered,
|
|
/// distributing one workgroup per compute unit across 256 CUs (8 XCDs).
|
|
///
|
|
/// Kernel arguments (passed via the argument buffer):
|
|
/// A - pointer to input vector A (N floats)
|
|
/// B - pointer to input vector B (N floats)
|
|
/// C - pointer to output vector C (N floats)
|
|
/// N - number of elements
|
|
|
|
extern "C" __global__ void vector_add(const float *__restrict__ A,
|
|
const float *__restrict__ B,
|
|
float *__restrict__ C, unsigned N) {
|
|
constexpr unsigned BLOCK_SIZE = 64;
|
|
unsigned gid = blockIdx.x * BLOCK_SIZE + threadIdx.x;
|
|
|
|
if (gid < N)
|
|
C[gid] = A[gid] + B[gid];
|
|
}
|